@@ -1,3 +1,4 @@
+/* $Id: httpd.c,v 1.3 2004/12/05 07:26:12 ichiro Exp $ */
 /*
  * Copyright (c) 2004
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -216,18 +217,21 @@ void httpd_proc(struct tparam *th2, int socket)
 			if (strcmp(cmd_cmd, "join") == 0) {
 				url_decode_rawdata(channel, cmd_cname);
 				channel_decode(channel2, channel);
-				sprintf(post_message, "JOIN %s\r\n",
+				sprintf(post_message, ":%s JOIN %s\r\n",
+					th2->real_nickname,
 					channel2);
 			} else if (strcmp(cmd_cmd, "part") == 0) {
 				url_decode_rawdata(channel, cmd_cname);
 				channel_decode(channel2, channel);
-				sprintf(post_message, "PART %s\r\n",
+				sprintf(post_message, ":%s PART %s\r\n",
+					th2->real_nickname,
 					channel2);
 			} else if (strcmp(cmd_cmd, "topic") == 0) {
 				url_decode_rawdata(channel, cmd_cname);
 				channel_decode(channel2, channel);
 				url_decode_jis(cmd_topic, cmd_buf);
-				sprintf(post_message, "TOPIC %s :%s\r\n",
+				sprintf(post_message, ":%s TOPIC %s :%s\r\n",
+					th2->real_nickname,
 					channel2, cmd_topic);
 			} else {
 				goto command_start;
@@ -359,9 +363,9 @@ index_start:
 		    th2->read_count[n]);
 	    } else {
 	sprintf(message,
-		   "%d <href=\"channel%d\">%s</a> \
+		   "* <a href=\"channel%d\">%s</a> \
 		    <a href=\"channel%d\">(%d)</a><br>",
-		    n, n, th2->name[n],
+		    n, th2->name[n],
 		    n + 50, th2->history_count[n] -
 		    th2->read_count[n]); 	
 	    }
