@@ -1,3 +1,4 @@
+/* $Id: keitai.c,v 1.5 2004/12/05 07:31:31 ichiro Exp $ */
 /*
  * Copyright (c) 2004
  *	Ichiro FUKUHARA <ichiro@ichiro.org>.
@@ -69,15 +70,18 @@ keitai_start(struct tparam *th)
 		sscanf(th->l_buff, ":%s JOIN :%[^,]", a1, a3);
 		if (a3[0] != '#') { /* for madoka4.2 */
 			sscanf(th->l_buff, ":%s JOIN %[^,]", a1, a3);
-			printf("madoka hack\n");
+#ifdef DEBUG
+			printf("JOIN: madoka hack\n");
+#endif
 		}
 		join_recv(th, a3);
 	}
 
 	if ((s = strstr(th->l_buff, "PART"))) {
+		strcpy(a3, s + 5);
 		sscanf(th->l_buff, ":%s PART %s :%*[^,]", a1, a3);
-		printf("%s\n", th->l_buff);
-		part_recv(th, a3);
+		if (strcmp(th->real_nickname, a1) == 0)
+			part_recv(th, a3);
  	}
 
 	/* catch PRIVMSGs */
@@ -87,7 +91,7 @@ keitai_start(struct tparam *th)
 
 	/* catch QUIT */
 	if ((s = strstr(th->l_buff, "QUIT"))) {
-		printf("QUIT:%s", th->l_buff);
+		printf("QUIT:%s\n", th->l_buff);
 	}
 
 	/* detect TOPIC */
@@ -105,7 +109,7 @@ keitai_start(struct tparam *th)
 
 	/* MODE */
 	if ((s = strstr(th->l_buff, "MODE"))) {
-		printf("MODE:%s", th->l_buff);
+		printf("MODE:%s\n", th->l_buff);
 	}
 
 	return (0);
@@ -236,7 +240,7 @@ int topic_recv(struct tparam *th, char *user, char *channel, char *topic)
 
 int part_recv(struct tparam *th, char *channel)
 {
-	int i;
+	int i, j, match = 255;
 	char channel2[C_NAME];
 
 	memset(channel2, 0, sizeof(channel2));
@@ -244,18 +248,53 @@ int part_recv(struct tparam *th, char *channel)
 	/* channel;  #hoge:*.jp -> %hoge */
 	channel_encode(channel2, channel);
 
-printf("part %s\n", channel2);
-printf("ch_count=%d\n", th->ch_count);
+#ifdef DEBUG
+	printf("part channel=%s\n", channel2);
+	printf("last ch number=%d\n", th->ch_count);
+#endif
 
 	 /* search exist channel */
 	for (i = 0; i <= th->ch_count; i++) {
-		if (strcmp(th->name[i], channel2) == 0)
+		if (strcmp(th->name[i], channel2) == 0) {
+			match = i;
 			break;
+		}
 	}
-printf("match count=%d\n", i);
 
+	if (match > th->ch_count)
+		return (0);
 
+	if (match == th->ch_count) {
+		memset(th->name[match], 0, sizeof(th->name[match]));
+		memset(th->topic[match], 0, sizeof(th->topic[match]));
+		memset(th->data[match], 0, sizeof(th->data[match]));
+		th->history_count[match] = 0;
+		th->read_count[match] = 0;
+	} else {
+	    for (i = match; i < th->ch_count; i++) {
+		memset(th->name[i], 0, sizeof(th->name[i]));
+		memset(th->topic[i], 0, sizeof(th->topic[i]));
+		memset(th->data[i], 0, sizeof(th->data[i]));
 
+		strcpy(th->name[i], th->name[i + 1]);
+		strcpy(th->topic[i], th->topic[i + 1]);
+
+		for (j = 0; j < th->history_count[i + 1]; j++) {
+			strcpy(th->data[i][j], th->data[i + 1][j]);
+		}
+		th->history_count[i] = th->history_count[i + 1];
+		th->read_count[i] = th->read_count[i + 1];
+	    }
+	    memset(th->name[th->ch_count], 0,
+		   sizeof(th->name[th->ch_count]));
+	    memset(th->topic[th->ch_count], 0,
+		   sizeof(th->topic[th->ch_count]));
+	    memset(th->data[th->ch_count], 0,
+		   sizeof(th->data[match]));
+	    th->history_count[th->ch_count] = 0;
+	    th->read_count[th->ch_count] = 0;
+	}
+	th->ch_count--;
 
 	return (0);
 }
@@ -272,14 +311,13 @@ int join_recv(struct tparam *th, char *channel)
 
 	/* search exist channel */
 	for (i = 0; i <= th->ch_count; i++) {
-		if (strstr(th->name[i], channel2))
+		if (strcmp(th->name[i], channel2) == 0)
 			return (0);
 	}
 
 	/* make new channel */
 	while (th->name[n][0] != '\0')
 		n++;
-
 	if (n > th->ch_count)
 		th->ch_count = n; /* largest channel number */
 
